"""
******************************************************************************
* @author  ARMCNC site:www.armcnc.net github:armcnc.github.io
******************************************************************************
"""

from .handwheel import HandWheel

class Package:

    def __init__(self, framework):
        self.framework = framework
        self.handwheel = HandWheel(self)
        self.init_status()

    def init_status(self):
        if self.framework.machine.machine_path != "":
            self.handwheel.joy_speed = self.framework.machine.get_user_config_items("HANDWHEEL")
            if self.handwheel.joy_speed["STATUS"] == "YES":
                self.set_status("handwheel", True)

    def set_status(self, package, status):
        if self.framework.machine.machine_path != "":
            if package == "handwheel":
                if status == "YES":
                    self.handwheel.start()
                else:
                    self.handwheel.stop()



"""
******************************************************************************
* @author  ARMCNC site:www.armcnc.net github:armcnc.github.io
******************************************************************************
"""

import logging
import colorlog

class Log:

    def __init__(self, utils):
        self.utils = utils
        self.logger = logging.getLogger(None)
        self.logger.handlers = []
        self.logger.setLevel(logging.DEBUG)
        console_fmt = "%(log_color)s%(asctime)s %(levelname)s: %(message)s"
        color_config = {
            "DEBUG": "cyan",
            "INFO": "green",
            "WARNING": "yellow",
            "ERROR": "red",
            "CRITICAL": "purple",
        }
        console_formatter = colorlog.ColoredFormatter(fmt=console_fmt, log_colors=color_config)
        console_handler = logging.StreamHandler()
        console_handler.setFormatter(console_formatter)
        self.logger.addHandler(console_handler)

    def debug(self, log):
        self.logger.debug(log)
        self.utils.service.service_write({"command": "launch:debug", "message": log, "data": False})

    def info(self, log):
        self.logger.info(log)
        self.utils.service.service_write({"command": "launch:info", "message": log, "data": False})

    def warning(self, log):
        self.logger.warning(log)
        self.utils.service.service_write({"command": "launch:warning", "message": log, "data": False})

    def error(self, log):
        self.logger.error(log)
        self.utils.service.service_write({"command": "launch:error", "message": log, "data": False})
